createJunction.default: default function for class of 'createJunction'

View source: R/createJunction.default.R

createJunction.defaultR Documentation

default function for class of createJunction

Description

this function constructs an object from class of createDiversion, acting as a junction in the basin which is able to aggregate outflow water from upper tributaries and/or objects in the upstream.

Usage

## Default S3 method:
createJunction(name = "junc1", downstream = NA, latlon =NULL)

Arguments

name

(optional) A string: the name of the junction

downstream

(optional) An object from either of classes of createAquifer , createRiver, createReservoir, createJunction, createDiversion, or createDemandSite; which outflow volume pours to it.

latlon

(optional) A vector of two elements: lat, lon in decimal degree representing the location of the object.

Value

An object from class of list

See Also

createJunction


WRSS documentation built on March 6, 2026, 9:07 a.m.