plot.sim: plot method for an WRSS object

View source: R/plot.sim.R

plot.simR Documentation

plot method for an WRSS object

Description

plot method for objects inherited from class of sim

Usage

## S3 method for class 'sim'
plot(x,...)

Arguments

x

an object from class of sim

...

other objects that can be passed to plot function

Author(s)

Rezgar Arabzadeh

See Also

sim


WRSS documentation built on March 6, 2026, 9:07 a.m.